BasesDecomposition
==================

.. currentmodule:: pykeen.nn.message_passing

.. autoclass:: BasesDecomposition
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~BasesDecomposition.forward
      ~BasesDecomposition.reset_parameters

   .. rubric:: Methods Documentation

   .. automethod:: forward
   .. automethod:: reset_parameters
